@@ -1,5 +1,6 @@
 import sys
 from math import ceil
+from multiprocessing import Process
 from multiprocessing import managers
 from multiprocessing import cpu_count
 from concurrent.futures import ThreadPoolExecutor
@@ -200,3 +201,36 @@ class QueueManager():
             return scraper.run()
         else:
             scraper.run()
+
+class InfluxDBWriter(Process):
+    def __init__(self, args, csv_chunks_queue):
+        multiprocessing.Process.__init__(self)
+        self.args = args
+        self.csv_chunks_queue = csv_chunks_queue
+        self.client = InfluxDBClient(url=self.args['INFLUX_URL'],
+                                     token=self.args['INFLUX_TOKEN'],
+                                     org=self.args['INFLUX_ORG'],
+                                     debug=False)
+        self.write_api = self.client.write_api(write_options=WriteOptions(
+                                               write_type=WriteType.batching,
+                                               batch_size=25_000,
+                                               flush_interval=12_000))
+
+    def run(self):
+        while True:
+            chunk = self.csv_chunks_queue.get()
+
+            if chunk is None:
+                self.terminate()
+                self.csv_chunks_queue.task_done()
+                break
+
+            self.write_api.write(org=self.args['INFLUX_ORG'],
+                                 bucket=self.args['INFLUX_BUCKET'],
+                                 record=chunk,
+                                 write_precision=WritePrecision.MS)
+            self.csv_chunks_queue.task_done()
+
+    def terminate(self):
+        self.write_api.__del__()
+        self.client.__del__()
